@@ -14,8 +14,8 @@ from sklearn.isotonic import IsotonicRegression
 from skgstat import estimators, models, binning
 from skgstat import plotting
 from skgstat.util import shannon_entropy
-from .MetricSpace import MetricSpace, MetricSpacePair
-from skgstat.interfaces.gstools import skgstat_to_gstools
+from .MetricSpace import MetricSpace, MetricSpacePair, ProbabalisticMetricSpace
+from skgstat.interfaces.gstools import skgstat_to_gstools, skgstat_to_krige
 
 class Variogram(object):
     """Variogram Class
@@ -37,6 +37,7 @@ class Variogram(object):
                  fit_sigma=None,
                  use_nugget=False,
                  maxlag=None,
+                 samples=None,
                  n_lags=10,
                  verbose=False,
                  **kwargs,
@@ -180,6 +181,13 @@ class Variogram(object):
             Note maxlag=0.5 will use half the maximum separating distance,
             this is not the same as 'median', which is the median of all
             separating distances
+        samples : float, int
+            If set to a non-None value point pairs are sampled
+            randomly. Two random subset of all points are chosen, and
+            the distance matrix is calculated only between these two
+            subsets. The size of each subset is set by `samples`: if <
+            1 it specifies a fraction of all points, if >= 1 it
+            specifies the number of points in each subset.
         n_lags : int
             Specify the number of lag classes to be defined by the binning
             function.
@@ -230,12 +238,18 @@ class Variogram(object):
                     np.zeros(len(coordinates))
                 ))
                 self._1d = True
-
             # handle maxlag for MetricSpace
             _maxlag = maxlag if maxlag and not isinstance(maxlag, str) and maxlag >= 1 else None
-            coordinates = MetricSpace(coordinates.copy(), dist_func, _maxlag)
+            if samples == None:
+                coordinates = MetricSpace(coordinates.copy(), dist_func, _maxlag)
+            else:
+                coordinates = ProbabalisticMetricSpace(coordinates.copy(), dist_func, _maxlag, samples=samples,
+                                                       rnd=self._kwargs.get("binning_random_state", None))
         elif dist_func != coordinates.dist_metric:
-            raise AttributeError("Distance metric of variogram differs from distance metric of coordinates")
+            raise AttributeError((
+                "Distance metric of variogram differs "
+                "from distance metric of coordinates"
+            ))
 
         # Set coordinates
         self._X = coordinates
@@ -245,7 +259,7 @@ class Variogram(object):
 
         # set verbosity
         self.verbose = verbose
-
+    
         # set values
         self._values = None
         # calc_diff = False here, because it will be calculated by fit() later
@@ -921,7 +935,7 @@ class Variogram(object):
         c = m.tocsc()
         c.data = c.indices
         rows = c.tocsr()
-        filt = sparse.csr.csr_matrix((m.indices < rows.data, m.indices, m.indptr))
+        filt = sparse.csr.csr_matrix((m.indices < rows.data, m.indices, m.indptr), m.shape)
         return m.multiply(filt)
 
     @property
@@ -2104,9 +2118,58 @@ class Variogram(object):
         -------
         :any:`CovModel`
             Corresponding GSTools covmodel.
+
+        Note
+        ----
+        In case you intend to use the
+        :func:`coordinates <skgstat.Variogram.coordinates>`
+        in a GSTools workflow, you need to transpose the coordinate
+        array like:
+
+        >> cond_pos Variogram.coordinates.T
+
         """
         return skgstat_to_gstools(self, **kwargs)
 
+    def to_gs_krige(self, **kwargs):
+        """
+        Instatiate a GSTools Krige class.
+
+        This can only export isotropic models.
+        Note: the `fit_variogram` is always set to `False`
+
+        Parameters
+        ----------
+        variogram : skgstat.Variogram
+            Scikit-GStat Variogram instamce
+        **kwargs
+            Keyword arguments forwarded to GSTools Krige.
+            Refer to :any:`Krige <gstools.krige.Krige>` to
+            learn about all possible options.
+            Note that the `fit_variogram` parameter will
+            always be False.
+
+        Raises
+        ------
+        ImportError
+            When GSTools is not installed.
+        ValueError
+            When GSTools version is not v1.3 or greater.
+        ValueError
+            When given Variogram model is not supported ('harmonize').
+
+        Returns
+        -------
+        :any:`Krige`
+            Instantiated GSTools Krige class.
+
+        See Also
+        --------
+        gstools.Krige
+
+        """
+        return skgstat_to_krige(self, **kwargs)
+
     def plot(self, axes=None, grid=True, show=True, hist=True):
         """Variogram Plot
 
